local mod_gui = require("mod-gui")
local version = 1

local on_player_created = function(event)
  local player = game.players[event.player_index]
  local character = player.character
  player.character = nil
  if character then
    character.destroy()
  end

  local r = global.chart_distance or 200
  player.force.chart(player.surface, {{player.position.x - r, player.position.y - r}, {player.position.x + r, player.position.y + r}})

  if not global.skip_cheat_menu then
    create_technologies_frame(player)
  end

end

local on_gui_click = function(event)
  local player = game.players[event.player_index]
  local gui = event.element
  if not (gui and gui.valid) then return end

  if gui.name == "button_technologies_researched" then
    player.force.research_all_technologies()
    gui.parent.destroy()
    create_cheat_frame(player)
    return
  end
  if gui.name == "button_technologies_normal" then
    gui.parent.destroy()
    create_cheat_frame(player)
    return
  end
  if gui.name == "button_use_cheat_mode" then
    player.cheat_mode = true
    gui.parent.destroy()
    create_day_frame(player)
    return
  end
  if gui.name == "button_no_cheat_mode" then
    gui.parent.destroy()
    create_day_frame(player)
    return
  end
  if gui.name == "button_yes_day" then
    player.surface.always_day = true
    gui.parent.destroy()
    create_character_frame(player)
    return
  end
  if gui.name =="button_no_day" then
    gui.parent.destroy()
    create_character_frame(player)
    return
  end
  if gui.name == "button_create_character" then
    player.create_character()
    gui.parent.destroy()
    return
  end
  if gui.name == "button_no_character" then
    gui.parent.destroy()
    return
  end
end

function create_technologies_frame(player)
  local frame = mod_gui.get_frame_flow(player).add{name = "technologies_frame", type = "frame", direction = "horizontal", caption={"msg-ask-technologies"}}
  frame.add{type = "button", name = "button_technologies_researched", caption = {"button-technologies-researched"}}
  frame.add{type = "button", name = "button_technologies_normal", caption = {"button-technologies-normal"}}
end

function create_cheat_frame(player)
  local frame = mod_gui.get_frame_flow(player).add{name = "cheat_frame", type = "frame", direction = "horizontal", caption={"msg-ask-cheat-mode"}}
  frame.add{type = "button", name="button_use_cheat_mode", caption={"button-use-cheat-mode"}}
  frame.add{type = "button", name="button_no_cheat_mode", caption={"button-no-cheat-mode"}}
end

function create_day_frame(player)
  local frame = mod_gui.get_frame_flow(player).add{name = "day_frame", type = "frame", direction = "horizontal", caption={"msg-ask-always-day"}}
  frame.add{type = "button", name="button_yes_day", caption={"button-yes-day"}}
  frame.add{type = "button", name="button_no_day", caption={"button-no-day"}}
end

function create_character_frame(player)
  local frame = mod_gui.get_frame_flow(player).add{name = "character_frame", type = "frame", direction = "horizontal", caption={"msg-ask-create-character"}}
  frame.add{type = "button", name="button_create_character", caption={"button-create-character"}}
  frame.add{type = "button", name="button_no_character", caption={"button-no-character"}}
end

local sandbox = {}

sandbox.events =
{
  [defines.events.on_player_created] = on_player_created,
  [defines.events.on_gui_click] = on_gui_click
}

sandbox.on_init = function()
  global.version = version
end

sandbox.on_configuration_changed = function(event)
end

sandbox.add_remote_interface = function()
  remote.add_interface("sandbox",
  {
    set_skip_intro = function(bool)
      global.skip_intro = bool
    end,
    set_chart_distance = function(value)
      global.chart_distance = tonumber(value)
    end,
    set_skip_cheat_menu = function(bool)
      global.skip_cheat_menu = bool
    end
  })
end

return sandbox
